==> geopytool-0.8.20.0.203.tar.gz: geopytool-0.8.20.0.203/geopytool/cnt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="__init__.py" line="140"/>
        <source>GeoPyTool</source>
        <translation>GeoPyTool</translation>
    </message>
    <message>
        <location filename="__init__.py" line="744"/>
        <source>You are using GeoPyTool </source>
        <translation>妳正在使用的是 GeoPyTool</translation>
    </message>
    <message>
        <location filename="__init__.py" line="745"/>
        <source>released on </source>
        <translation>發布日期為 </translation>
    </message>
    <message>
        <location filename="__init__.py" line="605"/>
        <source>Data File</source>
        <translation>數據文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="606"/>
        <source>Geochemistry</source>
        <translation>地球化學</translation>
    </message>
    <message>
        <location filename="__init__.py" line="607"/>
        <source>Calculation</source>
        <translation>多維度分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="608"/>
        <source>Structure</source>
        <translation>構造地質學</translation>
    </message>
    <message>
        <location filename="__init__.py" line="609"/>
        <source>Sedimentary</source>
        <translation>沉積相關</translation>
    </message>
    <message>
        <location filename="__init__.py" line="610"/>
        <source>Additional</source>
        <translation>附加功能</translation>
    </message>
    <message>
        <location filename="__init__.py" line="611"/>
        <source>MachineLearn</source>
        <translation>機器學習</translation>
    </message>
    <message>
        <location filename="__init__.py" line="612"/>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <location filename="__init__.py" line="613"/>
        <source>Language</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="615"/>
        <source>Combine</source>
        <translation>合並數據表</translation>
    </message>
    <message>
        <location filename="__init__.py" line="616"/>
        <source>Combine_transverse</source>
        <translation>合並轉置</translation>
    </message>
    <message>
        <location filename="__init__.py" line="618"/>
        <source>Flatten</source>
        <translation>二維數據拉平成壹維</translation>
    </message>
    <message>
        <location filename="__init__.py" line="620"/>
        <source>Trans</source>
        <translation>數據變換</translation>
    </message>
    <message>
        <location filename="__init__.py" line="622"/>
        <source>ReFormat</source>
        <translation>重新格式化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="624"/>
        <source>Open Data</source>
        <translation>導入數據</translation>
    </message>
    <message>
        <location filename="__init__.py" line="625"/>
        <source>Close Data</source>
        <translation>關閉文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="626"/>
        <source>Set Format</source>
        <translation>設置數據</translation>
    </message>
    <message>
        <location filename="__init__.py" line="627"/>
        <source>Fill Blank with 0</source>
        <translation>用零值填充空白</translation>
    </message>
    <message>
        <location filename="__init__.py" line="628"/>
        <source>Save Data</source>
        <translation>保存數據</translation>
    </message>
    <message>
        <location filename="__init__.py" line="629"/>
        <source>Quit App</source>
        <translation>退出程序</translation>
    </message>
    <message>
        <location filename="__init__.py" line="631"/>
        <source>Remove LOI</source>
        <translation>去除燒式量</translation>
    </message>
    <message>
        <location filename="__init__.py" line="632"/>
        <source>Auto</source>
        <translation>常規地化圖解計算自動生成</translation>
    </message>
    <message>
        <location filename="__init__.py" line="633"/>
        <source>TAS</source>
        <translation>TAS 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="634"/>
        <source>Trace</source>
        <translation>微量蛛網圖</translation>
    </message>
    <message>
        <location filename="__init__.py" line="635"/>
        <source>REE</source>
        <translation>稀土模式圖</translation>
    </message>
    <message>
        <location filename="__init__.py" line="636"/>
        <source>Pearce</source>
        <translation>Pearce 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="637"/>
        <source>Harker</source>
        <translation>Harker 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="638"/>
        <source>CIPW</source>
        <translation>CIPW</translation>
    </message>
    <message>
        <location filename="__init__.py" line="640"/>
        <source>QAPF</source>
        <translation>QAPF 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="641"/>
        <source>Saccani Plot</source>
        <translation>Saccani圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="642"/>
        <source>K2O-SiO2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="643"/>
        <source>Raman Strength</source>
        <translation>激光拉曼數據可視化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="644"/>
        <source>Fluid Inclusion</source>
        <translation>流體包裹體</translation>
    </message>
    <message>
        <location filename="__init__.py" line="645"/>
        <source>Harker Classical</source>
        <translation>經典 Harker 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="646"/>
        <source>TraceNew</source>
        <translation>新版微量元素</translation>
    </message>
    <message>
        <location filename="__init__.py" line="647"/>
        <source>ZrYSrTi</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="648"/>
        <source>TiAlCaMgMnKNaSi</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="650"/>
        <source>Stereo</source>
        <translation>極射赤平投影</translation>
    </message>
    <message>
        <location filename="__init__.py" line="651"/>
        <source>Rose</source>
        <translation>玫瑰花圖</translation>
    </message>
    <message>
        <location filename="__init__.py" line="653"/>
        <source>QFL</source>
        <translation>QFL 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="654"/>
        <source>QmFLt</source>
        <translation>QmFLt 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="655"/>
        <source>Clastic(sand-silt-clay)</source>
        <translation>陸源碎屑</translation>
    </message>
    <message>
        <location filename="__init__.py" line="656"/>
        <source>CIA/ICV/PIA/CIW/CIW&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="658"/>
        <source>ZirconCe</source>
        <translation>鋯石Ce 氧逸度</translation>
    </message>
    <message>
        <location filename="__init__.py" line="659"/>
        <source>ZirconCeOld</source>
        <translation>鋯石Ce 氧逸度舊版</translation>
    </message>
    <message>
        <location filename="__init__.py" line="660"/>
        <source>ZirconTiTemp</source>
        <translation>鋯石 Ti 溫度計</translation>
    </message>
    <message>
        <location filename="__init__.py" line="661"/>
        <source>RutileZrTemp</source>
        <translation>金紅石 Zr 溫度計</translation>
    </message>
    <message>
        <location filename="__init__.py" line="662"/>
        <source>Rb-Sr IsoTope</source>
        <translation>Rb-Sr同位素等時線</translation>
    </message>
    <message>
        <location filename="__init__.py" line="663"/>
        <source>Sm-Nd IsoTope</source>
        <translation>Sm-Nd同位素等時線</translation>
    </message>
    <message>
        <location filename="__init__.py" line="666"/>
        <source>X-Y plot</source>
        <translation>自定義平面圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="667"/>
        <source>X-Y-Z plot</source>
        <translation>自定義三角圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="668"/>
        <source>Cluster</source>
        <translation>譜系聚類分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="669"/>
        <source>MultiDimension</source>
        <translation>三維可視化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="671"/>
        <source>Distance</source>
        <translation>距離計算</translation>
    </message>
    <message>
        <location filename="__init__.py" line="673"/>
        <source>Statistics</source>
        <translation>數據統計</translation>
    </message>
    <message>
        <location filename="__init__.py" line="675"/>
        <source>ThreeD</source>
        <translation>三維可視化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="676"/>
        <source>TwoD</source>
        <translation>二維成分數據彩色可視化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="677"/>
        <source>TwoD Grey</source>
        <translation>二維成分數據灰度可視化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="679"/>
        <source>Histogram + KDE Curve</source>
        <translation>直方圖+核密度曲線</translation>
    </message>
    <message>
        <location filename="__init__.py" line="680"/>
        <source>Pie Chart</source>
        <translation>餅圖</translation>
    </message>
    <message>
        <location filename="__init__.py" line="681"/>
        <source>Bar Chart</source>
        <translation>柱條圖</translation>
    </message>
    <message>
        <location filename="__init__.py" line="683"/>
        <source>FA</source>
        <translation>因子分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="684"/>
        <source>PCA</source>
        <translation>主成分分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="685"/>
        <source>LDA</source>
        <translation>線性判別分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="686"/>
        <source>DT</source>
        <translation>深度決策樹</translation>
    </message>
    <message>
        <location filename="__init__.py" line="687"/>
        <source>MLP</source>
        <translation>多层感知机</translation>
    </message>
    <message>
        <location filename="__init__.py" line="689"/>
        <source>Check Update</source>
        <translation>檢查更新</translation>
    </message>
    <message>
        <location filename="__init__.py" line="690"/>
        <source>English Forum</source>
        <translation>英文論壇</translation>
    </message>
    <message>
        <location filename="__init__.py" line="691"/>
        <source>Github</source>
        <translation>Github</translation>
    </message>
    <message>
        <location filename="__init__.py" line="702"/>
        <source>Load Language</source>
        <translation>加載語言</translation>
    </message>
    <message>
        <location filename="__init__.py" line="735"/>
        <source>NetWork Error</source>
        <translation>網絡錯誤</translation>
    </message>
    <message>
        <location filename="__init__.py" line="744"/>
        <source>Version Online is </source>
        <translation>當前線上最新版本為 </translation>
    </message>
    <message>
        <location filename="__init__.py" line="768"/>
        <source>Version</source>
        <translation>檢查更新</translation>
    </message>
    <message>
        <location filename="__init__.py" line="753"/>
        <source>New version available.
 Download and update?</source>
        <translation>發現新版本，是否前往下載？</translation>
    </message>
    <message>
        <location filename="__init__.py" line="768"/>
        <source>This is the latest version.</source>
        <translation>已經是最新版本。</translation>
    </message>
    <message>
        <location filename="__init__.py" line="832"/>
        <source>Choose Language File</source>
        <translation>選擇語言文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1563"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="__init__.py" line="845"/>
        <source>Your Data mismatch this Function.
 Some Items missing?
 Or maybe there are blanks in items names?
 Or there are nonnumerical valueï¼</source>
        <translation>妳的數據沒能用於這壹功能,是否缺失項目或者有空白值?</translation>
    </message>
    <message>
        <location filename="__init__.py" line="848"/>
        <source>Your Data mismatch this Function.
 Error infor is:</source>
        <translation>妳的數據沒能夠運行這壹功能,錯誤信息為:</translation>
    </message>
    <message>
        <location filename="__init__.py" line="916"/>
        <source>Ready</source>
        <translation>完畢</translation>
    </message>
    <message>
        <location filename="__init__.py" line="898"/>
        <source>Everything fine and no need to set up.</source>
        <translation>圖件信息完整無需設置</translation>
    </message>
    <message>
        <location filename="__init__.py" line="902"/>
        <source>Items added, Modify in the Table to set up details.</source>
        <translation>設置項目已添加，請自行調整顏色分類等信息</translation>
    </message>
    <message>
        <location filename="__init__.py" line="916"/>
        <source>Blanks are now filled with 0s.</source>
        <translation>空白位置已經用零值填充</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1098"/>
        <source>Choose Data File</source>
        <translation>選擇數據文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1046"/>
        <source>Save Data File</source>
        <translation>存儲數據文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1210"/>
        <source>Done</source>
        <translation>完工！</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1210"/>
        <source>LOI has been removed!:</source>
        <translation>燒式量已經移除</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1563"/>
        <source>Your data contain no Q/A/P/F data.
 Maybe you need to run CIPW first?</source>
        <translation>妳的數據壓根就沒有包含 QAPF 信息，先 CIPW 算出來 QAPF 的值再說吧！</translation>
    </message>
</context>
</TS>

==> geopytool-0.9.21.0.2.tar.gz: geopytool-0.9.21.0.2/geopytool/cnt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="__init__.py" line="140"/>
        <source>GeoPyTool</source>
        <translation>GeoPyTool</translation>
    </message>
    <message>
        <location filename="__init__.py" line="744"/>
        <source>You are using GeoPyTool </source>
        <translation>妳正在使用的是 GeoPyTool</translation>
    </message>
    <message>
        <location filename="__init__.py" line="745"/>
        <source>released on </source>
        <translation>發布日期為 </translation>
    </message>
    <message>
        <location filename="__init__.py" line="605"/>
        <source>Data File</source>
        <translation>數據文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="606"/>
        <source>Geochemistry</source>
        <translation>地球化學</translation>
    </message>
    <message>
        <location filename="__init__.py" line="607"/>
        <source>Calculation</source>
        <translation>多維度分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="608"/>
        <source>Structure</source>
        <translation>構造地質學</translation>
    </message>
    <message>
        <location filename="__init__.py" line="609"/>
        <source>Sedimentary</source>
        <translation>沉積相關</translation>
    </message>
    <message>
        <location filename="__init__.py" line="610"/>
        <source>Additional</source>
        <translation>附加功能</translation>
    </message>
    <message>
        <location filename="__init__.py" line="611"/>
        <source>MachineLearn</source>
        <translation>機器學習</translation>
    </message>
    <message>
        <location filename="__init__.py" line="612"/>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <location filename="__init__.py" line="613"/>
        <source>Language</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="615"/>
        <source>Combine</source>
        <translation>合並數據表</translation>
    </message>
    <message>
        <location filename="__init__.py" line="616"/>
        <source>Combine_transverse</source>
        <translation>合並轉置</translation>
    </message>
    <message>
        <location filename="__init__.py" line="618"/>
        <source>Flatten</source>
        <translation>二維數據拉平成壹維</translation>
    </message>
    <message>
        <location filename="__init__.py" line="620"/>
        <source>Trans</source>
        <translation>數據變換</translation>
    </message>
    <message>
        <location filename="__init__.py" line="622"/>
        <source>ReFormat</source>
        <translation>重新格式化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="624"/>
        <source>Open Data</source>
        <translation>導入數據</translation>
    </message>
    <message>
        <location filename="__init__.py" line="625"/>
        <source>Close Data</source>
        <translation>關閉文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="626"/>
        <source>Set Format</source>
        <translation>設置數據</translation>
    </message>
    <message>
        <location filename="__init__.py" line="627"/>
        <source>Fill Blank with 0</source>
        <translation>用零值填充空白</translation>
    </message>
    <message>
        <location filename="__init__.py" line="628"/>
        <source>Save Data</source>
        <translation>保存數據</translation>
    </message>
    <message>
        <location filename="__init__.py" line="629"/>
        <source>Quit App</source>
        <translation>退出程序</translation>
    </message>
    <message>
        <location filename="__init__.py" line="631"/>
        <source>Remove LOI</source>
        <translation>去除燒失量</translation>
    </message>
    <message>
        <location filename="__init__.py" line="632"/>
        <source>Auto</source>
        <translation>常規地化圖解計算自動生成</translation>
    </message>
    <message>
        <location filename="__init__.py" line="633"/>
        <source>TAS</source>
        <translation>TAS 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="634"/>
        <source>Trace</source>
        <translation>微量蛛網圖</translation>
    </message>
    <message>
        <location filename="__init__.py" line="635"/>
        <source>REE</source>
        <translation>稀土模式圖</translation>
    </message>
    <message>
        <location filename="__init__.py" line="636"/>
        <source>Pearce</source>
        <translation>Pearce 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="637"/>
        <source>Harker</source>
        <translation>Harker 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="638"/>
        <source>CIPW</source>
        <translation>CIPW</translation>
    </message>
    <message>
        <location filename="__init__.py" line="640"/>
        <source>QAPF</source>
        <translation>QAPF 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="641"/>
        <source>Saccani Plot</source>
        <translation>Saccani圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="642"/>
        <source>K2O-SiO2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="643"/>
        <source>Raman Strength</source>
        <translation>激光拉曼數據可視化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="644"/>
        <source>Fluid Inclusion</source>
        <translation>流體包裹體</translation>
    </message>
    <message>
        <location filename="__init__.py" line="645"/>
        <source>Harker Classical</source>
        <translation>經典 Harker 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="646"/>
        <source>TraceNew</source>
        <translation>新版微量元素</translation>
    </message>
    <message>
        <location filename="__init__.py" line="647"/>
        <source>ZrYSrTi</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="648"/>
        <source>TiAlCaMgMnKNaSi</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="650"/>
        <source>Stereo</source>
        <translation>極射赤平投影</translation>
    </message>
    <message>
        <location filename="__init__.py" line="651"/>
        <source>Rose</source>
        <translation>玫瑰花圖</translation>
    </message>
    <message>
        <location filename="__init__.py" line="653"/>
        <source>QFL</source>
        <translation>QFL 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="654"/>
        <source>QmFLt</source>
        <translation>QmFLt 圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="655"/>
        <source>Clastic(sand-silt-clay)</source>
        <translation>陸源碎屑</translation>
    </message>
    <message>
        <location filename="__init__.py" line="656"/>
        <source>CIA/ICV/PIA/CIW/CIW&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="658"/>
        <source>ZirconCe</source>
        <translation>鋯石Ce 氧逸度</translation>
    </message>
    <message>
        <location filename="__init__.py" line="659"/>
        <source>ZirconCeOld</source>
        <translation>鋯石Ce 氧逸度舊版</translation>
    </message>
    <message>
        <location filename="__init__.py" line="660"/>
        <source>ZirconTiTemp</source>
        <translation>鋯石 Ti 溫度計</translation>
    </message>
    <message>
        <location filename="__init__.py" line="661"/>
        <source>RutileZrTemp</source>
        <translation>金紅石 Zr 溫度計</translation>
    </message>
    <message>
        <location filename="__init__.py" line="662"/>
        <source>Rb-Sr IsoTope</source>
        <translation>Rb-Sr同位素等時線</translation>
    </message>
    <message>
        <location filename="__init__.py" line="663"/>
        <source>Sm-Nd IsoTope</source>
        <translation>Sm-Nd同位素等時線</translation>
    </message>
    <message>
        <location filename="__init__.py" line="666"/>
        <source>X-Y plot</source>
        <translation>自定義平面圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="667"/>
        <source>X-Y-Z plot</source>
        <translation>自定義三角圖解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="668"/>
        <source>Cluster</source>
        <translation>譜系聚類分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="669"/>
        <source>MultiDimension</source>
        <translation>三維可視化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="671"/>
        <source>Distance</source>
        <translation>距離計算</translation>
    </message>
    <message>
        <location filename="__init__.py" line="673"/>
        <source>Statistics</source>
        <translation>數據統計</translation>
    </message>
    <message>
        <location filename="__init__.py" line="675"/>
        <source>ThreeD</source>
        <translation>三維可視化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="676"/>
        <source>TwoD</source>
        <translation>二維成分數據彩色可視化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="677"/>
        <source>TwoD Grey</source>
        <translation>二維成分數據灰度可視化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="679"/>
        <source>Histogram + KDE Curve</source>
        <translation>直方圖+核密度曲線</translation>
    </message>
    <message>
        <location filename="__init__.py" line="680"/>
        <source>Pie Chart</source>
        <translation>餅圖</translation>
    </message>
    <message>
        <location filename="__init__.py" line="681"/>
        <source>Bar Chart</source>
        <translation>柱條圖</translation>
    </message>
    <message>
        <location filename="__init__.py" line="683"/>
        <source>FA</source>
        <translation>因子分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="684"/>
        <source>PCA</source>
        <translation>主成分分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="685"/>
        <source>LDA</source>
        <translation>線性判別分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="686"/>
        <source>DT</source>
        <translation>深度決策樹</translation>
    </message>
    <message>
        <location filename="__init__.py" line="687"/>
        <source>MLP</source>
        <translation>多层感知机</translation>
    </message>
    <message>
        <location filename="__init__.py" line="689"/>
        <source>Check Update</source>
        <translation>檢查更新</translation>
    </message>
    <message>
        <location filename="__init__.py" line="690"/>
        <source>English Forum</source>
        <translation>英文論壇</translation>
    </message>
    <message>
        <location filename="__init__.py" line="691"/>
        <source>Github</source>
        <translation>Github</translation>
    </message>
    <message>
        <location filename="__init__.py" line="702"/>
        <source>Load Language</source>
        <translation>加載語言</translation>
    </message>
    <message>
        <location filename="__init__.py" line="735"/>
        <source>NetWork Error</source>
        <translation>網絡錯誤</translation>
    </message>
    <message>
        <location filename="__init__.py" line="744"/>
        <source>Version Online is </source>
        <translation>當前線上最新版本為 </translation>
    </message>
    <message>
        <location filename="__init__.py" line="768"/>
        <source>Version</source>
        <translation>檢查更新</translation>
    </message>
    <message>
        <location filename="__init__.py" line="753"/>
        <source>New version available.
 Download and update?</source>
        <translation>發現新版本，是否前往下載？</translation>
    </message>
    <message>
        <location filename="__init__.py" line="768"/>
        <source>This is the latest version.</source>
        <translation>已經是最新版本。</translation>
    </message>
    <message>
        <location filename="__init__.py" line="832"/>
        <source>Choose Language File</source>
        <translation>選擇語言文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1563"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="__init__.py" line="845"/>
        <source>Your Data mismatch this Function.
 Some Items missing?
 Or maybe there are blanks in items names?
 Or there are nonnumerical valueï¼</source>
        <translation>妳的數據沒能用於這壹功能,是否缺失項目或者有空白值?</translation>
    </message>
    <message>
        <location filename="__init__.py" line="848"/>
        <source>Your Data mismatch this Function.
 Error infor is:</source>
        <translation>妳的數據沒能夠運行這壹功能,錯誤信息為:</translation>
    </message>
    <message>
        <location filename="__init__.py" line="916"/>
        <source>Ready</source>
        <translation>完畢</translation>
    </message>
    <message>
        <location filename="__init__.py" line="898"/>
        <source>Everything fine and no need to set up.</source>
        <translation>圖件信息完整無需設置</translation>
    </message>
    <message>
        <location filename="__init__.py" line="902"/>
        <source>Items added, Modify in the Table to set up details.</source>
        <translation>設置項目已添加，請自行調整顏色分類等信息</translation>
    </message>
    <message>
        <location filename="__init__.py" line="916"/>
        <source>Blanks are now filled with 0s.</source>
        <translation>空白位置已經用零值填充</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1098"/>
        <source>Choose Data File</source>
        <translation>選擇數據文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1046"/>
        <source>Save Data File</source>
        <translation>存儲數據文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1210"/>
        <source>Done</source>
        <translation>完工！</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1210"/>
        <source>LOI has been removed!:</source>
        <translation>燒失量已經移除</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1563"/>
        <source>Your data contain no Q/A/P/F data.
 Maybe you need to run CIPW first?</source>
        <translation>妳的數據壓根就沒有包含 QAPF 信息，先 CIPW 算出來 QAPF 的值再說吧！</translation>
    </message>
</context>
</TS>
